<?php

namespace Drupal\simple_group_invite\Entity\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\simple_group_invite\Entity\SimpleGroupInvite;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for deleting Simple Group Invite entities.
 */
class SimpleGroupInviteDeleteForm extends EntityForm {

  /**
   * The Simple Group Invite entity.
   *
   * @var \Drupal\simple_group_invite\Entity\SimpleGroupInvite
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_group_invite_delete_form';
  }

  /**
   * Build the delete form.
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param \Drupal\simple_group_invite\Entity\SimpleGroupInvite $simple_group_invite
   *   The invite entity to be deleted.
   *
   * @return array
   *   The form array.
   */
  public function buildForm(array $form, FormStateInterface $form_state, SimpleGroupInvite $simple_group_invite = NULL) {
    $this->entity = $simple_group_invite;
    $group_id = $simple_group_invite->get('group_id')->getString();

    $form['title'] = [
      '#type' => 'markup',
      '#markup' => $this->t('Are you sure you want to delete the invite for @email?', ['@email' => $simple_group_invite->get('email')->value]),
      '#prefix' => '<h3>',  // Optional: Wrap the title in an <h2> tag.
      '#suffix' => '</h3>',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete'),
      '#button_type' => 'danger',
    ];

    $form['actions']['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => Url::fromRoute('entity.simple_group.canonical', ['simple_group' => $group_id]),
      '#attributes' => [
        'class' => ['button'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $group_id = $this->entity->get('group_id')->getString();
    $this->entity->delete();

    $this->messenger()->addStatus($this->t('Invite has been deleted.'));

    // Redirect back to the Simple Group page after deletion.
    $url = Url::fromRoute('entity.simple_group.canonical', ['simple_group' => $group_id]);
    $form_state->setRedirectUrl($url);
  }
}
