<?php

namespace Drupal\simple_group_invite\Entity;

use Drupal\Core\Entity\Annotation\ContentEntityType;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\user\UserInterface;

/**
 * Defines the Invite entity.
 *
 * @ContentEntityType(
 *   id = "simple_group_invite",
 *   label = @Translation("Simple Group Invite"),
 *   base_table = "simple_group_invite",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "email",
 *     "uuid" = "uuid"
 *   },
 *   handlers = {
 *     "access" = "Drupal\simple_group_invite\Entity\Access\SimpleGroupInviteAccessControlHandler",
 *     "views_data" = "Drupal\simple_group_invite\Entity\Handler\SimpleGroupInviteViewsData",
 *     "form" = {
 *       "add" = "Drupal\simple_group_invite\Entity\Form\SimpleGroupInviteAddForm",
 *       "delete" = "Drupal\simple_group_invite\Entity\Form\SimpleGroupInviteDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\simple_group_invite\Entity\Routing\SimpleGroupInviteRouteProvider",
 *     },
 *   },
 *   links = {
 *     "add-form" = "/simple-group/{simple_group_id}/invite",
 *     "delete-form" = "/simple_group_invite/{simple_group_invite}/delete",
 *   }
 * )
 */
class SimpleGroupInvite extends ContentEntityBase {

  /**
   * Get the email address of the invitee.
   */
  public function getEmail() {
    return $this->get('email')->value;
  }

  /**
   * Get the group ID.
   */
  public function getGroupId() {
    return $this->get('group_id')->target_id;
  }

  /**
   * Get the status of the invite.
   */
  public function getStatus() {
    return $this->get('status')->value;
  }

  /**
   * Set the status of the invite.
   */
  public function setStatus($status): static {
    $this->set('status', $status);
    return $this;
  }

  /**
   * Base field definitions for the entity.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    // Email field.
    $fields['email'] = BaseFieldDefinition::create('email')
      ->setLabel(t('Email'))
      ->setRequired(TRUE);

    // Group reference field.
    $fields['group_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Group ID'))
      ->setSetting('target_type', 'simple_group')
      ->setRequired(TRUE);

    // Invite status.
    $fields['status'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Status'))
      ->setSetting('allowed_values', [
        'pending' => 'Pending',
        'accepted' => 'Accepted',
        'rejected' => 'Rejected',
      ])
      ->setDefaultValue('pending');

    return $fields;
  }
}
