<?php

namespace Drupal\simple_group_invite\Plugin\views\argument_default;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Cache\CacheableDependencyInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\simple_group\Entity\SimpleGroup;
use Drupal\views\Annotation\ViewsArgumentDefault;
use Drupal\views\Plugin\views\argument_default\ArgumentDefaultPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin to extract the Simple Group ID from the URL.
 *
 * @ViewsArgumentDefault(
 *   id = "groupiffromurl",
 *   title = @Translation("Group ID from URL")
 * )
 */
class GroupIdFromUrl extends ArgumentDefaultPluginBase implements CacheableDependencyInterface {

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected RouteMatchInterface $routeMatch;

  /**
   * Constructs a new Product instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, RouteMatchInterface $route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->routeMatch = $route_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * Override the behavior of the argument to provide the group ID from URL.
   *
   * @param string $argument
   *   The argument from the URL.
   *
   * @return bool
   *   TRUE if the argument was successfully validated, FALSE otherwise.
   */
  public function validateArgument($argument): bool {
    // You can add validation logic here if necessary.
    return is_numeric($argument);
  }

  /**
   * Override to get the default argument from the URL.
   *
   * @return string|null
   *   The group ID or NULL if not found.
   */
  public function getArgument(): ?int {
    $group = ($this->routeMatch->getParameter('simple_group'));
    if ($group instanceof SimpleGroup) {
      return $group->id();
    }
    // Ensure the ID is numeric.
    return NULL;
  }

  public function getCacheContexts(): array {
    return ['url'];
  }

  public function getCacheMaxAge(): int {
    return Cache::PERMANENT;
  }

}
