<?php

namespace Drupal\simple_group_invite\Service;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\simple_group\Service\SimpleGroupEntityService;
use Drupal\user\UserInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SimpleGroupInviteService {

  /**
   * @var \Drupal\Core\Session\AccountInterface
   */
  private AccountInterface $currentUser;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private EntityTypeManagerInterface $entityTypeManager;

  /**
   * @var \Drupal\Core\Logger\LoggerChannelInterface $logger
   */
  private LoggerChannelInterface $logger;

  /**
   * @var \Drupal\simple_group\Service\SimpleGroupEntityService $simpleGroupEntityService
   */
  private SimpleGroupEntityService $simpleGroupEntityService;

  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('logger.factory'),
      $container->get(SimpleGroupEntityService::class),
    );
  }

  public function __construct(EntityTypeManagerInterface $entity_type_manager, AccountInterface $current_user, LoggerChannelFactoryInterface $logger_factory, SimpleGroupEntityService $simple_group_entity_service) {
    $this->entityTypeManager = $entity_type_manager;
    $this->currentUser = $current_user;
    $this->logger = $logger_factory->get('simple_group_invite');
    $this->simpleGroupEntityService = $simple_group_entity_service;
  }

  public function getInvites(UserInterface $user = null): array {
    if (empty($user)) {
      $user = $this->currentUser;
    }

    $email = $user->getEmail();

    $invites = $this->entityTypeManager->getStorage('simple_group_invite')
      ->loadByProperties(['email' => $email]);

    return $invites;
  }
}
