<?php

namespace Drupal\simple_group_invite;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Drupal\simple_group\Service\SimpleGroupEntityService;
use Symfony\Component\DependencyInjection\Definition;
use Symfony\Component\DependencyInjection\Reference;

class SimpleGroupInviteServiceProvider extends ServiceProviderBase {
  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container): void {
    // Register the custom route provider.
    $container->register('simple_group_invite.route_subscriber',
      'Drupal\simple_group_invite\Routing\SimpleGroupInviteRouteSubscriber')
      ->addTag('event_subscriber');
  }

  public function register(ContainerBuilder $container): void {
    parent::register($container);

    $ramwServices = [
      'Drupal\simple_group_invite\Service\SimpleGroupInviteService' => [
        'autowired' => true,
        'public' => true,
        'arguments' => [
          new Reference('entity_type.manager'),
          new Reference('current_user'),
          new Reference('logger.factory'),
          new Reference(SimpleGroupEntityService::class),
        ]
      ],
    ];

    foreach ($ramwServices as $class => $options){
      if ($container->hasDefinition($class)) {
        continue;
      }

      $definition = new Definition($class);
      if ($options['autowired']) {
        $definition->setAutowired(TRUE);
      }
      if ($options['public']) {
        $definition->setPublic(TRUE);
      }
      if ($options['arguments']) {
        $definition->setArguments($options['arguments']);
      }

      $container->setDefinition($class, $definition);

    }
  }

}
