<?php

namespace Drupal\simple_group\Entity\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Provides a page to select a Simple Group Type before adding a Simple Group.
 */
class SimpleGroupController extends ControllerBase {

  /**
   * Displays a list of Simple Group Types with links to add Simple Groups.
   */
  public function addPage() {
    $types = $this->entityTypeManager()->getStorage('simple_group_type')->loadMultiple();

    if (empty($types)) {
      // If no types exist, inform the user and provide a link to create one.
      return [
        '#markup' => $this->t('No Simple Group Types are available. Please <a href="@url">create one</a> before adding a Simple Group.', [
          '@url' => Url::fromRoute('entity.simple_group_type.add_form')->toString(),
        ]),
        '#allowed_tags' => ['a'],
      ];
    }

    $items = [];
    foreach ($types as $type) {
      $url = Url::fromRoute('entity.simple_group.add_form', ['simple_group_type' => $type->id()]);
      $items[] = Link::fromTextAndUrl($type->label(), $url)->toString();
    }

    return [
      '#theme' => 'item_list',
      '#items' => $items,
    ];
  }

  /**
   * The _title_callback for the simple-group.add-page route.
   *
   * @return string
   *   The page title.
   */
  public function addPageTitle() {
    return $this->t('Add A New Simple Group');
  }

}
