<?php

namespace Drupal\simple_group\Entity\Form;

use Drupal;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\simple_group\Entity\SimpleGroupInterface;

/**
 * Form controller for Group edit forms.
 *
 * @ingroup simple_group
 */
class SimpleGroupForm extends ContentEntityForm {

  /**
   * The entity being used by this form.
   *
   * @var \Drupal\simple_group\Entity\SimpleGroupInterface
   */
  protected $entity;

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    // Set the bundle (type) from the route parameter.
    if (! $this->entity->getSimpleGroupType()) {
      // Handle cases where no type is provided.
      throw new \Exception('A Simple Group Type must be selected before creating a Simple Group.');
    }

    $form = parent::form($form, $form_state);

    // The status (published) field.
    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#default_value' => $this->entity->isPublished(),
      '#description' => $this->t('Check to make this Simple Group active.'),
    ];

    // The owner field.
    $form['uid'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Owner'),
      '#target_type' => 'user',
      '#default_value' => $this->entity->getOwner(),
      '#description' => $this->t('Select the owner of this Simple Group.'),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->entity->save();

    // Display success message.
    $t_args = [
      '@type' => $this->entity->getSimpleGroupType()->label(),
      '%title' => $this->entity->label(),
    ];

    $this->messenger()->addStatus($this->operation == 'edit'
      ? $this->t('@type %title has been updated.', $t_args)
      : $this->t('@type %title has been created.', $t_args)
    );

    $form_state->setRedirect('entity.simple_group.collection');
  }

}
