<?php

namespace Drupal\simple_group\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;
use Drupal\Core\Entity\Annotation\ConfigEntityType;

/**
 * Defines the Group type entity.
 *
 * @ConfigEntityType(
 *   id = "simple_group_type",
 *   label = @Translation("Simple Group Type"),
 *   handlers = {
 *     "list_builder" = "Drupal\simple_group\Entity\Handler\SimpleGroupTypeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\simple_group\Entity\Form\SimpleGroupTypeForm",
 *       "edit" = "Drupal\simple_group\Entity\Form\SimpleGroupTypeForm",
 *       "delete" = "Drupal\simple_group\Entity\Form\SimpleGroupTypeDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "simple_group_type",
 *   admin_permission = "administer site configuration",
 *   bundle_of = "simple_group",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "description" = "description",
 *     "uuid" = "uuid",
 *   },
 *   config_export = {
 *     "description",
 *     "id",
 *     "label",
 *     "uuid",
 *   },
 *   links = {
 *     "add-form" = "/admin/simple-group/types/add",
 *     "edit-form" = "/admin/structure/simple-group-types/manage/{simple_group_type}",
 *     "delete-form" = "/admin/structure/simple-group-types/manage/{simple_group_type}/delete",
 *     "collection" = "/admin/structure/simple-group-types"
 *   }
 * )
 */
class SimpleGroupType extends ConfigEntityBundleBase implements SimpleGroupTypeInterface {

  /**
   * The Group type ID.
   *
   * @var string
   */
  protected string $id;

  /**
   * The Group type label.
   *
   * @var string
   */
  protected string $label;

  /**
   * The Group type description.
   *
   * @var string
   */
  protected $description;

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function setDescription($description) {
    $this->description = $description;
    return $this;
  }

}
