<?php

namespace Drupal\simple_group\Service;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\node\Entity\Node;
use Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Session\AccountInterface;

class SimpleGroupEntityService implements ContainerInjectionInterface {

  /**
   * @var \Drupal\Core\Session\AccountInterface
   */
  private AccountInterface $currentUser;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private EntityTypeManagerInterface $entityTypeManager;

  private \Drupal\Core\Logger\LoggerChannelInterface $logger;

  /**
   * @var ModuleExtensionList $pathResolver
   */
  private ModuleExtensionList $pathResolver;

  /**
   * @var string[] $possibleGroupNames
   */
  private array $possibleGroupNames;

  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('logger.factory'),
      $container->get('extension.path.resolver'),
    );
  }

  public function __construct(EntityTypeManagerInterface $entity_type_manager, AccountInterface $current_user, LoggerChannelFactoryInterface $logger_factory, ModuleExtensionList $extension_path = NULL) {
    $this->entityTypeManager = $entity_type_manager;
    $this->currentUser = $current_user;
    $this->logger = $logger_factory->get('simple_group');
    $this->pathResolver = $extension_path;
  }

  /**
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Exception
   */
  public function createGroup(string $bundle, string $name = null): EntityInterface {
    if (empty($name)) {
      $name = $this->createGroupName();
    }

    $group = $this->entityTypeManager->getStorage('simple_group')
      ->create([
        'type' => $bundle,
        'label' => $name,
      ]);

    $group->save();

    return $group;
  }

  /**
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function isValidGroup(int $groupId) : bool {

    $group = $this->entityTypeManager->getStorage('simple_group')
      ->load($groupId);

    if (empty($group)){
      return FALSE;
    }

    return TRUE;

  }

  /**
   * Gets two random words from the group name file.
   *
   * @throws \Exception
   */
  private function createGroupName(): string {
    $this->generateGroupNames();

    $random_keys = array_rand($this->possibleGroupNames, 2);

    $groupName = ucfirst(strtolower($this->possibleGroupNames[$random_keys[0]]))
      . ucfirst(strtolower($this->possibleGroupNames[$random_keys[1]]));

    $groups = $this->entityTypeManager->getStorage('simple_group')
      ->loadByProperties(['label' => $groupName]);

    $attempts = 0;
    $finalGroupName = $groupName;
    while (count($groups) > 0) {
      $finalGroupName = $groupName . $attempts;
      $groups = $this->entityTypeManager->getStorage('simple_group')
        ->loadByProperties(['label' => $finalGroupName]);
      $attempts += 1;
    }

    return $finalGroupName;
  }

  /**
   * Opens the words files and returns its contents.
   *
   * @throws \Exception
   */
  private function loadGroupNameChoices(): bool|string {
    $module_path = $this->pathResolver->getPath('simple_group');
    $file_path = $module_path . '/words/animals.txt';

    if (!file_exists($file_path) || !is_readable($file_path)) {
      throw new Exception('The specified file does not exist or is not readable.');
    }

    return file_get_contents($file_path);
  }

  /**
   * Pulls all possible words into our class for reuse.
   *
   * @throws \Exception
   */
  private function generateGroupNames(): void {
    if (empty($this->possibleGroupName)) {
      $content = $this->loadGroupNameChoices();
      $lines = explode(PHP_EOL, $content);
      $lines = array_filter($lines); // Remove any empty lines

      if (count($lines) < 2) {
        throw new \Exception('The file does not contain enough lines.');
      }
      $this->possibleGroupNames = $lines;
    }
  }
}
